@@ -3,6 +3,7 @@
 
 import pytest
 
+from pymarketcap.tests.consts import asyncparms
 from pymarketcap.tests.exchange import (
     assert_types,
     assert_consistence
@@ -17,8 +18,7 @@ pym = Pymarketcap()
 @pytest.mark.end2end
 def test_every_exchange(event_loop):
     async def wrapper():
-        async with AsyncPymarketcap(queue_size=50,
-                                    consumers=50) as apym:
+        async with AsyncPymarketcap(**asyncparms) as apym:
             res = []
             show_msg = True
             async for exc in apym.every_exchange():
